OC.L10N.register(
    "settings",
    {
    "Private" : "Приватност",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Видливо само за луѓето кои се потврдени преку телефонски број",
    "Local" : "Локално",
    "Only visible to people on this instance and guests" : "Видливо само за корисници на оваа истанца и гости",
    "Federated" : "Федерален",
    "Only synchronize to trusted servers" : "Синхронизирај само со доверливи сервери",
    "Published" : "Објавено",
    "Synchronize to trusted servers and the global and public address book" : "Синхронизирај само со доверливи сервери и со глобални и јавни адресари",
    "Verify" : "Потврди",
    "Verifying …" : "Потврдување …",
    "Unable to change password" : "Неможе да се промени лозинката",
    "Very weak password" : "Многу слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Така така лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Groups" : "Групи",
    "Group list is empty" : "Листата во групата е празна",
    "Unable to retrieve the group list" : "Неможе да се вчита листата со групи",
    "{actor} added you to group {group}" : "{actor} те додаде во групата {group}",
    "You added {user} to group {group}" : "Го додаде {user} во групата {group}",
    "{actor} added {user} to group {group}" : "{actor} го додаде {user} во групата {group}",
    "An administrator added you to group {group}" : "Администраторот те додаде во групата {group}",
    "An administrator added {user} to group {group}" : "Администраторот го додаде {user} во групата {group}",
    "{actor} removed you from group {group}" : "{actor} те отстрани од групата {group}",
    "You removed {user} from group {group}" : "Го отстрани {user} од групата {group}",
    "{actor} removed {user} from group {group}" : "{actor} го отстрани {user} од групата {group}",
    "An administrator removed you from group {group}" : "Администраторот те отстрани од групата {group}",
    "An administrator removed {user} from group {group}" : "Администраторот го отстрани {user} од групата {group}",
    "Your <strong>group memberships</strong> were modified" : "Вашето <strong>групно членство</strong> е изменето",
    "{actor} changed your password" : "{actor} ја промени вашата лозика",
    "You changed your password" : "Ја променивте вашата лозинка",
    "Your password was reset by an administrator" : "Вашата лозинка е ресетирана од страна на администраторот",
    "Your password was reset" : "Вашата лозинка е ресетирана",
    "{actor} changed your email address" : "{actor} ја промени вашата адреса на е-пошта",
    "You changed your email address" : "Ја променивте вашата адреса на е-пошта",
    "Your email address was changed by an administrator" : "Вашата адреса на е-пошта е променета од страна на администраторот",
    "You created an app password for a session named \"{token}\"" : "Креиравте лозинка за апликација за сесијата \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Администраторот креираше лозинка за апликација за сесијата \"{token}\"",
    "You deleted app password \"{token}\"" : "Избришавте лозинка за апликација \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ја променивте лозинката за апликација \"{token}\" во \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Издадовте дозвола за пристап со лозинка на апликација до вашите датотеки \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Одземавте дозвола за пристап со лозинка на апликација до вашите датотеки \"{token}\"",
    "Security" : "Безбедност",
    "You successfully logged in using two-factor authentication (%1$s)" : "Успешно се најавивте со користење на двофакторна автентикација (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Неуспешен обид за најава со двофакторна автентикација (%1$s)",
    "Remote wipe was started on %1$s" : "Далечинското бришење е започна на  %1$s",
    "Remote wipe has finished on %1$s" : "Далечинското бришење заврши на %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Вашата <strong>лозинка</strong> или <strong>е-пошта</strong> е променета",
    "Settings" : "Параметри",
    "Could not remove app." : "Не може да ја се избрише апликацијата.",
    "Could not update app." : "Не може да ја се ажурира апликацијата.",
    "Wrong password" : "Погрешна лозинка",
    "Unable to change personal password" : "Неможе да се промени сопствената лозинката",
    "Saved" : "Зачувано",
    "Unable to change password. Password too long." : "Неможе да се промени лозинката. Лозинката е премногу долга.",
    "Authentication error" : "Грешка во автентикација",
    "Wrong admin recovery password. Please check the password and try again." : "Погрешна лозинка за поврат на администраторот. Ве молам проверете ја лозинката и пробајте повторно.",
    "Administrator documentation" : "Документација за администратор",
    "User documentation" : "Документација за корисник",
    "Invalid SMTP password." : "Грешна SMTP лозинка.",
    "Email setting test" : "Тест за параметри на е-пошта",
    "Well done, %s!" : "Добро сторено, %s!",
    "If you received this email, the email configuration seems to be correct." : "Ако ја примивте оваа порака, тоа значи дека конфигурацијата за е-пошта е правилно поставена.",
    "Email could not be sent. Check your mail server log" : "Порака преку Е-пошта неможе да се испрати. Проверете го записот во е-пошта серверот",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Се случи грешка при праќање на порака. Ве молам проверете ги вашите параметри. (Error: %s)",
    "Invalid mail address" : "Неправилна електронска адреса/пошта",
    "Settings saved" : "Параматрите се зачувани",
    "Unable to change full name" : "Не можам да го променам целото име",
    "Unable to change email address" : "Не можам да ја променам е-пошта адресата",
    "Unable to set invalid phone number" : "Неможе да се постави невалиден телефонски број",
    "Unable to set invalid website" : "Неможе да се постави невалидена веб страна",
    "Some account data was invalid" : "Некој податоци во корисничка сметка се невалидни",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "За да ја потврдите вашата Твитер сметка, постирајте го следниов твит (напишете го постот без празни места)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "За да ја потврдите вашата веб страна, зачувајте ја следнава содржина на вашата веб страна како: '.well-known/CloudIdVerificationCode.txt' (напишете го текстот во една линија)",
    "%1$s changed your password on %2$s." : "%1$s ја промени вашата лозинка на %2$s.",
    "Your password on %s was changed." : "Вашата лозинка на %s е променета.",
    "Your password on %s was reset by an administrator." : "Вашата лозинка на %s беше ресетирана од страна на администраторот.",
    "Your password on %s was reset." : "Вашата лозинка на %s е ресетирана.",
    "Password for %1$s changed on %2$s" : "Лозинката на %1$s е променета на %2$s",
    "Password changed for %s" : "Лозинката на %s е променета",
    "If you did not request this, please contact an administrator." : "Ако не сте го побарале ова, ве молиме контактирајте со администраторот.",
    "Your email address on %s was changed." : "Вашата адреса за е-пошта на %s беше променета.",
    "Your email address on %s was changed by an administrator." : "Вашата адреса за е-пошта на %s беше променета од страна на администраторот.",
    "Email address for %1$s changed on %2$s" : "Адресата за е-пошта за %1$s е променета на %2$s",
    "Email address changed for %s" : "Адресата за е-пошта за %s е променета",
    "The new email address is %s" : "Новата адреса за е-пошта е %s",
    "Your %s account was created" : "Вашата %s сметка е креирана",
    "Welcome aboard" : "Добредојдовте",
    "Welcome aboard %s" : "Добредојдовте %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Добредојдовте на вашата %s сметка, можете да додавате, чувате и да ги споделувате вашите податоци.",
    "Set your password" : "Поставете ваша лозинка",
    "Go to %s" : "Оди до %s",
    "Install Client" : "Инсталирај клиент",
    "Apps" : "Аппликации",
    "Personal" : "Лично",
    "Administration" : "Администрација",
    "Users" : "Корисници",
    "Additional settings" : "Дополнителни параметри",
    "Artificial Intelligence" : "Вештачка интелигенција",
    "Administration privileges" : "Административни привилегии",
    "Groupware" : "Групни производи",
    "Overview" : "Преглед",
    "Basic settings" : "Основни параметри",
    "Sharing" : "Споделување",
    "Availability" : "Достапност",
    "Calendar" : "Календар",
    "Personal info" : "Лични податоци",
    "Mobile & desktop" : "Мобилен & компјутер",
    "Email server" : "Сервер за е-пошта",
    "Background jobs" : "Задачи кој се извршуваат во позадина",
    "Unlimited" : "Неограничено",
    "Verifying" : "Потврдување",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Во базата недостасуваат некој опционални колони. Поради фактот што додавањето колони во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-columns\" ќе бидат додадени оние колони што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени колоните, некој карактеристики ќе се подобрат и можат да ја подобрат употребата и безбедноста.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Во базата недостасуваат некој примарни клучеви. Поради фактот што додавањето на примарни клучеви во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-primary-keys\" ќе бидат додадени оние примарни клучеви што недостасуваат и инстанцата непречено ќе работи.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
    "Disabled" : "Оневозможено",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Овозможен е стар формат за криптирање од страна на серверот. Препорачуваме да го оневозможите ова.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
    "Supported" : "Поддржано",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP се чини дека не е правилно поставена за да испраќа барања до променливите на околината на системот. Тестот со getenv(\"PATH\") враќа само празен одговор.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP модулот OPcache не е вчитан. За да имате подобри перформанси е препорачливо да го вчитате во вашата PHP инсталација.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Антивирана е конфигурација која е само за чирање. Ова спречува поставување на некои конфигурации преку веб-интерфејсот. Понатаму, датотеката треба да се пребрише рачно за секое ажурирање.",
    "Architecture" : "Архитектура",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Вашата база на податоци не работи со нивото на изолација со \"READ COMMITTED\". Ова може да предизвика проблеми кога повеќе дејства се извршуваат паралелно.",
    "Profile information" : "Информации за профилот",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Слика на профил, име и презиме, е-пошта, телефонски број, адреса, њеб страна, Twitter, организација, улога, наслов, биографиј и дали вашиот профил е овозможен",
    "Nextcloud settings" : "Nextcloud параметри",
    "Task:" : "Задачa:",
    "Enable" : "Овозможи",
    "Machine translation" : "Машински превод",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Машинскиот превод може да се имплементира од различни апликации. Овде можете да ја дефинирате предноста на апликациите за машинско преведување што сте ги инсталирале во моментот.",
    "Text processing" : "Обработка на текст",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Задачите за обработка на текст може да се имплементираат од различни апликации. Овде можете да поставите која апликација треба да се користи за која задача.",
    "Here you can decide which group can access certain sections of the administration settings." : "Овде можете да одлучите која група може да пристапи до одредени делови од параметрите за администрација.",
    "Unable to modify setting" : "Неможе да се ажурираат параметрите",
    "None" : "Ништо",
    "Allow apps to use the Share API" : "Дозволете апликациите да го користат API-то за споделување",
    "Allow resharing" : "Дозволи повторно споделување",
    "Allow sharing with groups" : "Дозволи споделување со групи",
    "Restrict users to only share with users in their groups" : "Ограничи корисниците да споделуваат со корисници во своите групи",
    "Allow users to share via link and emails" : "Дозволи на корисниците да споделуваат со линкови и е-пошта",
    "Allow public uploads" : "Дозволи јавен аплоуд",
    "Always ask for a password" : "Секогаш прашувај за лозинка",
    "Enforce password protection" : "Наметни заштита на лозинка",
    "Enforce expiration date" : "Наметни датум на траење",
    "Set default expiration date for shares to other servers" : "Постави основен рок на траење за споделувањата со други сервери",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ако се овозможени автоматско пополнување \"иста група\" и \"интеграција на телефонски број\", доволно е да се совпадне или да се прикаже на корисникот.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "озволете автоматско пополнување кога го внесувате целосното име или адресата на е-пошта (игнорирање што недостасува совпаѓање со именикот и сте во иста група)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Покажете го текстот за одрекување од одговорност на страницата за поставување јавен линк. (Се прикажува само кога листата со датотеки е скриена)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Овој текст ќе биде прикажан на страната со јавниот линк кога листата на датотеки е сокриена.",
    "Default share permissions" : "Стандардни дозволи за споделување",
    "Two-Factor Authentication" : "Двофакторна автентикација",
    "Enforce two-factor authentication" : "Задолжителна двофакторна автентикација",
    "Limit to groups" : "Ограничување на групи",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Задолжителна двофакторна автентикација може да се постави само за одредени групи.",
    "Two-factor authentication is enforced for all members of the following groups." : "Двофакторна автентикација е задолжителна за членови на следниве групи.",
    "Enforced groups" : "Задолжителни групи",
    "Two-factor authentication is not enforced for members of the following groups." : "Двофакторна автентикација не е задолжителна за членови на следниве групи.",
    "Excluded groups" : "Исклучени групи",
    "Save changes" : "Зачувај ги промените",
    "Update to {update}" : "Надгради на {update}",
    "Remove" : "Отстрани ",
    "Featured" : "Истакнати",
    "This app is supported via your current Nextcloud subscription." : "Оваа апликација е е дозволена за вашиот налог.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Истакнати апликации се развиени од и во рамките на заедницата. Тие нудат централизирана функционалност и се спремни за користење.",
    "Disable all" : "Оневозможи ги сите",
    "Download and enable all" : "Преземи и овозможи ги сите",
    "All apps are up-to-date." : "Сите апликации се ажурирани.",
    "Icon" : "Икона",
    "Name" : "Име",
    "Version" : "Верзија",
    "Level" : "Ниво",
    "Actions" : "Акции",
    "Results from other categories" : "Резултати од други категории",
    "No apps found for your version" : "За вашата верзија не се пронајдени апликации",
    "_%n app has an update available_::_%n apps have an update available_" : ["За %n апликација има достапно ажурирање","За %n апликации има достапно ажурирање"],
    "_Update_::_Update all_" : ["Ажурирај","Ажурирај ги сите"],
    "Group name" : "Име на група",
    "Type" : "Вид",
    "Learn more" : "Научи повеќе",
    "Confirm" : "Потврди",
    "Cancel" : "Откажи",
    "View in store" : "Преглед во продавницата за апликации",
    "Visit website" : "Посети ја веб страната",
    "Admin documentation" : "Документација за администратор",
    "Developer documentation" : "Документација за програмери",
    "Details" : "Детали",
    "All" : "Сите",
    "Limit app usage to groups" : "Ограничување за користење на апликации во групи",
    "No results" : "Нема резултати",
    "Update to {version}" : "Надгради на {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Оваа апликација нема доделена минимална верзија. Може да настане грешка во иднина.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Оваа апликација нема доделена максимална верзија. Може да настане грешка во иднина.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Оваа апликација не може да се инсталира затоа што следниве зависности не се исполнети:",
    "Author" : "Автор",
    "Categories" : "Категории",
    "Resources" : "Ресурси",
    "Documentation" : "Документација",
    "Report a bug" : "Пријави грешка",
    "Changelog" : "Листа на промени",
    "Google Chrome for Android" : "Google Chrome за Android",
    "{productName} iOS app" : "{productName} iOS апликација",
    "{productName} Android app" : "{productName} Android апликација",
    "{productName} Talk for iOS" : "{productName} Talk за iOS",
    "{productName} Talk for Android" : "{productName} Talk за Android",
    "This session" : "Оваа сесија",
    "Device name" : "Име на уред",
    "Marked for remote wipe" : "Означи за далечинско бришење",
    "Device settings" : "Параметри за уреди",
    "Allow filesystem access" : "Дозвола за пристап до податоци",
    "Rename" : "Преименувај",
    "Revoke" : "Одземи",
    "Wipe device" : "Избриши уред",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Одземањето на овој токен може да спречи бришење на вашиот уред ако сè уште не е избришано.",
    "Device" : "Уред",
    "Last activity" : "Последна активност",
    "Devices & sessions" : "Уреди и сесии",
    "Web, desktop and mobile clients currently logged in to your account." : "Клиенти за веб, компјутер и мобелен кој моментално се поврзани на твојата сметка.",
    "Error while creating device token" : "Грешка при креирање на токен за уред",
    "App name" : "Име на апликација",
    "Create new app password" : "Креирај нова лозинка за апликација",
    "Could not copy app password. Please copy it manually." : "Неможе да се копира лозинката за апликација. Ве молиме копирајте ја рачно.",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Користете ги акредитивите подолу за да ја конфигурирате вашата апликација или уред. Од безбедносни причини оваа лозинка ќе се прикаже само еднаш.",
    "Login" : "Најава",
    "Password" : "Лозинка",
    "Show QR code for mobile apps" : "Прикажи QR код за апликација на мобилен телефон",
    "Use system cron service to call the cron.php file every 5 minutes." : "Го користи системскиот Cron сервис и го повикува cron.php секој 5 минути.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Потребен е PHP POSIX додаток. Погледни во  {linkstart}PHP документацијата{linkend} за повеќе детали.",
    "Unable to update background job mode" : "Не може да се ажурира режимот на работа во позадина",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "За серверот да работи правилно, важно е да ги конфигурирате процедурите кој се извршуваат во позадина. За големи истанци 'Cron' е препорачаната поставка. Погледнете ја документацијата за повеќе информации.",
    "Last job execution ran {time}. Something seems wrong." : "Последно извршување на задачите: {time}. Нешто не е во ред.",
    "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
    "Background job did not run yet!" : "Сеуште нема извршено ниедна задача!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Препорачано)",
    "Unable to update profile default setting" : "Неможе да се ажурираат стандардните параметри за профилот",
    "Profile" : "Профил",
    "Unable to update server side encryption config" : "Неможе да се ажурираат параметрите за енкрипција од страна на серверот",
    "Server-side encryption" : "Енкрипција на страна на серверот",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Енкрипцијата на страна на серверот овозможува да ги криптирате датотеките што се поставени на овој сервер. Ова доаѓа со ограничувања како намалување на перформансите, па овозможете го ова само доколку е потребно.",
    "Enable server-side encryption" : "Овозможи енкрипција на страна на серверот",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Нема вчитано модул за енкрипција, ве молиме овозможете модул за енкрипција во менито со апликации.",
    "Select default encryption module:" : "Изберете стандарден модул за шифрирање:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Треба да ги мигрирате клучевите за криптирање од стариот систем (ownCloud <= 8.0) за енкрипција во нови. Овозможете \"Стандарден додаток за енкрипција\" и стартувајте ја командата {command}",
    "Enable encryption" : "Овозможи енкрипција",
    "Please read carefully before activating server-side encryption:" : "Ве молиме внимателно прочитајте пред да активирате енкрипција од страна на серверот:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Откако ќе биде овозможено енкрипција, сите датотеки што се поставени на серверот од таа точка натаму ќе бидат шифрирани на серверот. Ќе може да се оневозможи енкрипција подоцна ако активниот модул за шифрирање ја поддржува таа функција и сите предуслови (на пример, поставување на копче за враќање) се исполнети.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Самата енкрипција не гарантира безбедност на системот. Ве молиме погледнете ја документацијата за повеќе информации за тоа како функционира апликацијата за шифрирање и за поддржаните случаи на употреба.",
    "Be aware that encryption always increases the file size." : "Бидете свесни дека енкрипцијата секогаш ја зголемува големината на датотеката.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Секогаш е добро да создавате редовни резервни кории на вашите податоци, во случај на енкрипција, осигурајте се да ги зачувате и клучевите за шифрирање заедно со вашите податоци.",
    "This is the final warning: Do you really want to enable encryption?" : "Ова е последно предупредување: Дали навистина сакате да овозможите енкрипција?",
    "Submit" : "Испрати",
    "Rename group" : "Преименувај група",
    "Current password" : "Моментална лозинка",
    "New password" : "Нова лозинка",
    "Change password" : "Смени лозинка",
    "Choose your profile picture" : "Избери за фотографија за профилот",
    "Please select a valid png or jpg file" : "Изберете png или jpg датотека",
    "Error setting profile picture" : "Грешка при поставување на фотографија за профилот",
    "Error cropping profile picture" : "Грешка при сечење на фотографија за профилот",
    "Error saving profile picture" : "Грешка при зачувување на фотографија за профилот",
    "Error removing profile picture" : "Грешка при бришење на фотографија за профилот",
    "Your profile picture" : "Ваша фотографија на профилот",
    "Upload profile picture" : "Прикачи фотографија на профилот",
    "Choose profile picture from Files" : "Избери фотографија на профилот од датотеките",
    "Remove profile picture" : "Избриши фотографија на профилот",
    "The file must be a PNG or JPG" : "Датотеката мора да биде PNG или JPG",
    "Picture provided by original account" : "Слика обезбедена од оригинална сметка",
    "Set as profile picture" : "Постави фотографија на профилот",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Имајте предвид дека може да потрае до 24 часа за да се ажурира аватарот насекаде.",
    "Enter your date of birth" : "Внесете го вашиот датум на раѓање",
    "You are using {s}{usage}{/s}" : "Користите {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Користите {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Член сте на следниве групи",
    "Your full name" : "Вашето целосно име",
    "Email options" : "Е-пошта параметри",
    "Remove primary email" : "Избриши примарна е-пошта",
    "Delete email" : "Избриши е-пошта",
    "This address is not confirmed" : "Оваа адреса не е потврдена",
    "Unset as primary email" : "Острани од примарна е-пошта",
    "Set as primary email" : "Постави како примарна е-пошта",
    "Additional email address {index}" : "Дополнителна е-пошта {index}",
    "Unable to delete primary email address" : "Неможе да се избрише примарната е-пошта",
    "Unable to update primary email address" : "Не може да се ажурира примарната е-пошта адреса",
    "Unable to add additional email address" : "Не може да се додаде дополнителна е-пошта адреса",
    "Unable to update additional email address" : "Не може да се ажурира дополнителната е-пошта адреса",
    "Unable to delete additional email address" : "Не може да се избрише дополнителната е-пошта адреса",
    "Primary email for password reset and notifications" : "Примарна Е-пошта за ресетирање на лозинка и известувања",
    "No email address set" : "Нема поставено адреса за е-пошта ",
    "Derived from your locale ({weekDayName})" : "Произлезено од вашата локација ({weekDayName})",
    "Your headline" : "Вашиот наслов",
    "Unable to update language" : "Не може да се ажурира јазикот",
    "Help translate" : "Помогни во преводот",
    "No language set" : "Не е поставен јазик",
    "Unable to update locale" : "Не може да се ажурира локалната локација",
    "Week starts on {firstDayOfWeek}" : "Неделата започнува во {firstDayOfWeek}",
    "No locale set" : "Нема поставено локална локација",
    "Your city" : "Град",
    "Your organisation" : "Вашата организација",
    "Your phone number" : "Вашиот телефонски број",
    "Edit your Profile visibility" : "Уредете ја видливоста на вашиот профил",
    "Unable to update profile enabled state" : "Неможе да се ажурира достапноста на профилот",
    "Enable profile" : "Овозможи профил",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Порестриктивни параметри за видливост или опсег се почитува на вашиот профил. На пример, ако видливоста е поставена на \"Прикажи на сите\", а опсегот е поставен на \"Приватно\", се почитува \"Приватно\".",
    "Unable to update visibility of {displayId}" : "Неможе да се ажурира видливоста на {displayId}",
    "Your role" : "Ваша улога",
    "Your website" : "Ваша вебстрана",
    "Unable to update {property}" : "Неможе да се ажурира {property}",
    "No {property} set" : "Нема поставено {property}",
    "Change scope level of {property}, current scope is {scope}" : "Променете го нивото на опсегот на {property}, моменталниот опсег е {scope}",
    "Unable to update federation scope of the primary {property}" : "Не може да се ажурира опсегот на федерацијата на примарните {property}",
    "Unable to update federation scope of additional {property}" : "Не може да се ажурира опсегот на федерацијата на дополнителни {property}",
    "Add additional email" : "Додади дополнителна е-пошта",
    "Add" : "Додади",
    "Create" : "Креирај",
    "Change" : "Измени",
    "Delete" : "Избриши",
    "Reshare" : "Пресподели",
    "Default language" : "Стандарден јазик",
    "Common languages" : "Заеднички јазици",
    "Other languages" : "Други јазици",
    "Password change is disabled because the master key is disabled" : "Ресетирање на лозинка е оневозможено бидејќи главниот клуч е оневозможен",
    "No accounts" : "Нема сметки",
    "Manager" : "Менаџер",
    "Display name" : "Име и презиме",
    "Either password or email is required" : "Внесување на лозинка или Е-пошта е задолжително",
    "Password (required)" : "Лозинка (задолжително)",
    "Email (required)" : "Е-пошта (задолжително)",
    "Email" : "Е-пошта",
    "Quota" : "Квота",
    "Language" : "Јазик",
    "Set default language" : "Постави стандарден јазик",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} сметка …","{userCount} сметки …"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} сметка","{userCount} сметки"],
    "Total rows summary" : "Резиме на вкупно редови",
    "Scroll to load more rows" : "Одете надолу за да се вчитаат повеќе редови",
    "Password or insufficient permissions message" : "Порака за лозинка или недоволна дозвола",
    "Avatar" : "Аватар",
    "Account name" : "Корисничко име",
    "Group admin for" : "Администратор на група",
    "Storage location" : "Локација на складиште",
    "First login" : "Прво најавување",
    "Last login" : "Последно најавување",
    "{size} used" : "искористено {size}",
    "Delete account" : "Избриши сметка",
    "Resend welcome email" : "Повторно испрати е-пошта порака за добредојде",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Во случај да го изгубите уредот или да излезете од компанијата, можете далечински да ги избришете податоците од сите уреди кој се конектирани со корисникот {userid}. Ова работи само доколку уредот е поврзан на интернет.",
    "Remote wipe of devices" : "Далечинско бришење на уреди",
    "Wipe {userid}'s devices" : "Бришење уред на корисникот {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Целосно бришење на сметка на {userid} вклучувајќи и сопствените податоци, апликации итн.",
    "Account deletion" : "Бришење на сметката",
    "Delete {userid}'s account" : "Избриши го корисникот {userid}",
    "Welcome mail sent!" : "Испратена е-пошта порака за добредојде!",
    "Change display name" : "Промена на името",
    "Set the language" : "Постави јазик",
    "Done" : "Готово",
    "Edit" : "Уреди",
    "Account management settings" : "Параметри за кориснички менаџмент",
    "Visibility" : "Видливост",
    "Show language" : "Прикажи јазик",
    "Show storage path" : "Прикажи патека на складиште",
    "Show last login" : "Прикажи последно најавување",
    "Send email" : "Испрати пошта",
    "Defaults" : "Стандарди",
    "Default quota" : "Стандардна квота",
    "Select default quota" : "Избери стандардна квота",
    "Server error while trying to complete WebAuthn device registration" : "Грешка на серверот при обид за комплетирање на регистрацијата на WEBAuthn уред",
    "Passwordless authentication requires a secure connection." : "За најавување без лозинка потребно е да се користи безбедна врска.",
    "Add WebAuthn device" : "Додади WebAuthn уред",
    "Please authorize your WebAuthn device." : "Авторизирајте го вашиот WebAuthn уред.",
    "Adding your device …" : "Додавање на вашиот уред ...",
    "Unnamed device" : "Уреди без име",
    "Passwordless Authentication" : "Најавување без лозинка",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Поставете ја вашата сметка за најавување без лозинка притоа следете ги FIDO2 стандардите.",
    "No devices configured." : "Нема конфигурирани уреди",
    "The following devices are configured for your account:" : "Следниве уреди се конфигурирани за вашата сметка:",
    "Your browser does not support WebAuthn." : "Вашиот прелистувач не поддржува WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Како администратор, можете детално да го прилагодите однесувањето на споделувањето. Погледнете ја документацијата за повеќе информации.",
    "You need to enable the File sharing App." : "Треба да ја овозможите апликацијата Споделување на датотеки.",
    "All accounts" : "Сите сметки",
    "Admins" : "Администратори",
    "Sending…" : "Испраќа…",
    "Email sent" : "Е-порака пратена",
    "Location" : "Локација",
    "Profile picture" : "Фотографија",
    "About" : "За",
    "Full name" : "Име и презиме",
    "Additional email" : "Дополнителна е-пошта",
    "Headline" : "Наслов",
    "Organisation" : "Организација",
    "Phone number" : "Телефонски број",
    "Role" : "Улога",
    "X (formerly Twitter)" : "X (поранешен Twitter)",
    "Website" : "ВЕБ страна",
    "Profile visibility" : "Видливост на профилот",
    "Locale" : "Локација",
    "First day of week" : "Прв ден од неделата",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Не е достапно бидејќи ова својство е потребно за основна функционалност, вклучувајќи споделување датотеки и покани од календар",
    "Your apps" : "Ваши апликации",
    "Active apps" : "Активни апликации",
    "Disabled apps" : "Оневозможени апликации",
    "Updates" : "Ажурирања",
    "App bundles" : "Пакети со апликации",
    "Featured apps" : "Истакнати апликации",
    "Supported apps" : "Поддржани апликации",
    "Show to everyone" : "Прикажи на сите",
    "Show to logged in accounts only" : "Прикажи само на најавени корисници",
    "Hide" : "Сокриј",
    "Download and enable" : "Преземи и овозможи",
    "Disable" : "Оневозможи",
    "Allow untested app" : "Дозволи не тестирана апликација",
    "The app will be downloaded from the App Store" : "Апликацијата ќе биде преземена преку продавницата за апликации",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Апликацијата не е означена дека е компатибилна со вашата верзија на Nextcloud. Доколку продолжите апликацијата ќе се инсталира. Имајте на ум дека апликацијата може да не работи како што очекувате.",
    "Unknown" : "Непознат",
    "Never" : "Никогаш",
    "An error occurred during the request. Unable to proceed." : "Настана грешка во процесот. Не може да продолжи.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Оваа апликација неможе да се овозможи бидејќи ќе го направи серверот нестабилен",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Оваа апликација е овозможена но треба да биде надоградена. Ќе бидете пренасочени кон страната за надоградување за 5 секунди.",
    "Do you really want to wipe your data from this device?" : "Дали навистина сакате да ја избришете содржината од овој уред?",
    "Confirm wipe" : "Потврди бришење",
    "Error while wiping the device with the token" : "Грешка при бришење на уред со токен",
    "Error while updating device token name" : "Грешка при промена на името за токен на уред",
    "Error while updating device token scope" : "Грешка при ажурирање на токен за уред",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Има испратено премногу барање од вашата мрежа. Обидете се подоцна повторно или контактирајте го администраторот.",
    "Error" : "Грешка",
    "Forum" : "Форум",
    "Legal notice" : "Правно известување",
    "Privacy policy" : "Политика за приватност",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Отвори ја документацијата",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Важно е да овозможите на серверот да испраќа е-пошта пораки, поради можноста за ресетирање на лозинки и известувања.",
    "Send mode" : "Начин на испраќање",
    "Encryption" : "Енкрипција",
    "Sendmail mode" : "Модул за испраќање на е-пошта",
    "From address" : "Од адреса",
    "Server address" : "Адреса на сервер",
    "Port" : "Порта",
    "Authentication" : "Автентикација",
    "Authentication required" : "Потребна е автентификација",
    "Credentials" : "Акредитиви",
    "SMTP Password" : "SMTP лозинка",
    "Save" : "Зачувај",
    "Test and verify email settings" : "Тестирај и потврди ги параметрите за електронска пошта",
    "Security & setup warnings" : "Предупредувања за сигурност & параметри",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Важно е за безбедноста и перформансите на вашата истанца дека сè е правилно конфигурирано. Да ви помогнеме во тоа, правиме неколку автоматски проверки. Погледнете ја документација за повеќе информации.",
    "All checks passed." : "Сите проверки се поминати.",
    "There are some errors regarding your setup." : "Постојат некои грешки во врска со инсталацијата.",
    "There are some warnings regarding your setup." : "Постојат некои предупредувања во врска со инсталацијата.",
    "Checking for system and security issues." : "Проверка на системот и безбедносна проверка.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Ве молиме двојно проверете ги <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">упатствата за инсталација ↗</a>, и проверете ги грешките или предупредувањата во <a href=\"%2$s\">записникот</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Провери ја безбедноста на твојот Nextcloud преку <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">нашиот безбедносен скенер ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Причини зошто да го користите Nextcloud во вашата организација",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Развиена од {communityopen}Nextcloud заедницата{linkclose}, {githubopen}изворениот код{linkclose} е лиценциран според {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Лајкни ја нашата Facebook страна",
    "Follow us on Mastodon" : "Следете не на Mastodon",
    "Check out our blog" : "Проверете го нашиот блог",
    "Subscribe to our newsletter" : "Претплатете се на нашиот билтен",
    "Use a second factor besides your password to increase security for your account." : "Користете втор фактор и покрај вашата лозинка за да ја зголемите безбедноста на вашата сметка.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Доколку користите друга апликација за поврзување на Nextcloud, осигурајте се дека имате креирано лозинка за секоја апликација пред да овозможите втор фактор.",
    "Set default expiration date for shares" : "Постави основен рок на траење за споделувањата",
    "Your biography" : "Ваша биографија",
    "You are using <strong>{usage}</strong>" : "Користите <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Користите <strong>{usage}</strong> од <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
